pub trait PartialEq<Rhs = Self>where
Rhs: ?Sized,{
// Required method
fn eq(&self, other: &Rhs) -> bool;
// Provided method
fn ne(&self, other: &Rhs) -> bool { ... }
}Expand description
Trait for comparisons using the equality operator.
Implementing this trait for types provides the == and != operators for
those types.
x.eq(y) can also be written x == y, and x.ne(y) can be written x != y.
We use the easier-to-read infix notation in the remainder of this documentation.
This trait allows for comparisons using the equality operator, for types
that do not have a full equivalence relation. For example, in floating point
numbers NaN != NaN, so floating point types implement PartialEq but not
Eq. Formally speaking, when Rhs == Self, this trait corresponds
to a partial equivalence relation.
Implementations must ensure that eq and ne are consistent with each other:
a != bif and only if!(a == b).
The default implementation of ne provides this consistency and is almost
always sufficient. It should not be overridden without very good reason.
If PartialOrd or Ord are also implemented for Self and Rhs, their methods must also
be consistent with PartialEq (see the documentation of those traits for the exact
requirements). It’s easy to accidentally make them disagree by deriving some of the traits and
manually implementing others.
The equality relation == must satisfy the following conditions
(for all a, b, c of type A, B, C):
-
Symmetry: if
A: PartialEq<B>andB: PartialEq<A>, thena == bimpliesb == a; and -
Transitivity: if
A: PartialEq<B>andB: PartialEq<C>andA: PartialEq<C>, thena == bandb == cimpliesa == c. This must also work for longer chains, such as whenA: PartialEq<B>,B: PartialEq<C>,C: PartialEq<D>, andA: PartialEq<D>all exist.
Note that the B: PartialEq<A> (symmetric) and A: PartialEq<C>
(transitive) impls are not forced to exist, but these requirements apply
whenever they do exist.
Violating these requirements is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Cross-crate considerations
Upholding the requirements stated above can become tricky when one crate implements PartialEq
for a type of another crate (i.e., to allow comparing one of its own types with a type from the
standard library). The recommendation is to never implement this trait for a foreign type. In
other words, such a crate should do impl PartialEq<ForeignType> for LocalType, but it should
not do impl PartialEq<LocalType> for ForeignType.
This avoids the problem of transitive chains that criss-cross crate boundaries: for all local
types T, you may assume that no other crate will add impls that allow comparing T == U. In
other words, if other crates add impls that allow building longer transitive chains U1 == ... == T == V1 == ..., then all the types that appear to the right of T must be types that the
crate defining T already knows about. This rules out transitive chains where downstream crates
can add new impls that “stitch together” comparisons of foreign types in ways that violate
transitivity.
Not having such foreign impls also avoids forward compatibility issues where one crate adding
more PartialEq implementations can cause build failures in downstream crates.
Derivable
This trait can be used with #[derive]. When derived on structs, two
instances are equal if all fields are equal, and not equal if any fields
are not equal. When derived on enums, two instances are equal if they
are the same variant and all fields are equal.
How can I implement PartialEq?
An example implementation for a domain in which two books are considered the same book if their ISBN matches, even if the formats differ:
enum BookFormat {
Paperback,
Hardback,
Ebook,
}
struct Book {
isbn: i32,
format: BookFormat,
}
impl PartialEq for Book {
fn eq(&self, other: &Self) -> bool {
self.isbn == other.isbn
}
}
let b1 = Book { isbn: 3, format: BookFormat::Paperback };
let b2 = Book { isbn: 3, format: BookFormat::Ebook };
let b3 = Book { isbn: 10, format: BookFormat::Paperback };
assert!(b1 == b2);
assert!(b1 != b3);How can I compare two different types?
The type you can compare with is controlled by PartialEq’s type parameter.
For example, let’s tweak our previous code a bit:
// The derive implements <BookFormat> == <BookFormat> comparisons
#[derive(PartialEq)]
enum BookFormat {
Paperback,
Hardback,
Ebook,
}
struct Book {
isbn: i32,
format: BookFormat,
}
// Implement <Book> == <BookFormat> comparisons
impl PartialEq<BookFormat> for Book {
fn eq(&self, other: &BookFormat) -> bool {
self.format == *other
}
}
// Implement <BookFormat> == <Book> comparisons
impl PartialEq<Book> for BookFormat {
fn eq(&self, other: &Book) -> bool {
*self == other.format
}
}
let b1 = Book { isbn: 3, format: BookFormat::Paperback };
assert!(b1 == BookFormat::Paperback);
assert!(BookFormat::Ebook != b1);By changing impl PartialEq for Book to impl PartialEq<BookFormat> for Book,
we allow BookFormats to be compared with Books.
A comparison like the one above, which ignores some fields of the struct,
can be dangerous. It can easily lead to an unintended violation of the
requirements for a partial equivalence relation. For example, if we kept
the above implementation of PartialEq<Book> for BookFormat and added an
implementation of PartialEq<Book> for Book (either via a #[derive] or
via the manual implementation from the first example) then the result would
violate transitivity:
#[derive(PartialEq)]
enum BookFormat {
Paperback,
Hardback,
Ebook,
}
#[derive(PartialEq)]
struct Book {
isbn: i32,
format: BookFormat,
}
impl PartialEq<BookFormat> for Book {
fn eq(&self, other: &BookFormat) -> bool {
self.format == *other
}
}
impl PartialEq<Book> for BookFormat {
fn eq(&self, other: &Book) -> bool {
*self == other.format
}
}
fn main() {
let b1 = Book { isbn: 1, format: BookFormat::Paperback };
let b2 = Book { isbn: 2, format: BookFormat::Paperback };
assert!(b1 == BookFormat::Paperback);
assert!(BookFormat::Paperback == b2);
// The following should hold by transitivity but doesn't.
assert!(b1 == b2); // <-- PANICS
}Examples
let x: u32 = 0;
let y: u32 = 1;
assert_eq!(x == y, false);
assert_eq!(x.eq(&y), false);Required Methods
Provided Methods
Implementors
impl PartialEq for TryReserveErrorKind
impl PartialEq for AsciiChar
impl PartialEq for core::cmp::Ordering
impl PartialEq for Infallible
impl PartialEq for FromBytesWithNulError
impl PartialEq for core::fmt::Alignment
impl PartialEq for DebugAsHex
impl PartialEq for Sign
impl PartialEq for AtomicOrdering
impl PartialEq for SimdAlign
impl PartialEq for IpAddr
impl PartialEq for Ipv6MulticastScope
impl PartialEq for SocketAddr
impl PartialEq for FpCategory
impl PartialEq for IntErrorKind
impl PartialEq for core::slice::GetDisjointMutError
impl PartialEq for SearchStep
impl PartialEq for core::sync::atomic::Ordering
impl PartialEq for BacktraceStatus
impl PartialEq for VarError
impl PartialEq for SeekFrom
impl PartialEq for std::io::error::ErrorKind
impl PartialEq for Shutdown
impl PartialEq for BacktraceStyle
impl PartialEq for RecvTimeoutError
impl PartialEq for std::sync::mpsc::TryRecvError
impl PartialEq for Colons
impl PartialEq for Fixed
impl PartialEq for Numeric
impl PartialEq for chrono::format::OffsetPrecision
impl PartialEq for Pad
impl PartialEq for ParseErrorKind
impl PartialEq for SecondsFormat
impl PartialEq for chrono::month::Month
impl PartialEq for RoundingError
impl PartialEq for chrono::weekday::Weekday
impl PartialEq for subtle_encoding::error::Error
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::CheckTxType
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::MisbehaviorType
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::request::Value
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::response::Value
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::response_apply_snapshot_chunk::Result
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::response_offer_snapshot::Result
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::response_process_proposal::ProposalStatus
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::response_verify_vote_extension::VerifyStatus
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::tx_record::TxAction
impl PartialEq for tenderdash_proto::tenderdash_grpc::crypto::public_key::Sum
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::BlockIdFlag
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::SignedMsgType
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::VoteExtensionType
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::evidence::Sum
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::version_params::ConsensusVersion
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::CheckTxType
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::MisbehaviorType
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::request::Value
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::response::Value
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::response_apply_snapshot_chunk::Result
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::response_offer_snapshot::Result
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::response_process_proposal::ProposalStatus
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::response_verify_vote_extension::VerifyStatus
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::tx_record::TxAction
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::crypto::public_key::Sum
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::BlockIdFlag
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::SignedMsgType
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::VoteExtensionType
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::evidence::Sum
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::version_params::ConsensusVersion
impl PartialEq for bool
impl PartialEq for char
impl PartialEq for f16
impl PartialEq for f32
impl PartialEq for f64
impl PartialEq for f128
impl PartialEq for i8
impl PartialEq for i16
impl PartialEq for i32
impl PartialEq for i64
impl PartialEq for i128
impl PartialEq for isize
impl PartialEq for !
impl PartialEq for str
impl PartialEq for u8
impl PartialEq for u16
impl PartialEq for u32
impl PartialEq for u64
impl PartialEq for u128
impl PartialEq for ()
impl PartialEq for usize
impl PartialEq for tenderdash_proto::google::protobuf::Duration
impl PartialEq for Timestamp
impl PartialEq for ByteString
impl PartialEq for UnorderedKeyError
impl PartialEq for alloc::collections::TryReserveError
impl PartialEq for CString
impl PartialEq for FromVecWithNulError
impl PartialEq for IntoStringError
impl PartialEq for NulError
impl PartialEq for FromUtf8Error
impl PartialEq for Layout
impl PartialEq for LayoutError
impl PartialEq for AllocError
impl PartialEq for TypeId
impl PartialEq for ByteStr
impl PartialEq for CharTryFromError
impl PartialEq for ParseCharError
impl PartialEq for DecodeUtf16Error
impl PartialEq for TryFromCharError
impl PartialEq for CpuidResult
impl PartialEq for CStr
impl PartialEq for FromBytesUntilNulError
impl PartialEq for core::fmt::Error
impl PartialEq for FormattingOptions
impl PartialEq for PhantomPinned
impl PartialEq for Assume
impl PartialEq for Ipv4Addr
impl PartialEq for Ipv6Addr
impl PartialEq for AddrParseError
impl PartialEq for SocketAddrV4
impl PartialEq for SocketAddrV6
impl PartialEq for ParseFloatError
impl PartialEq for core::num::error::ParseIntError
impl PartialEq for core::num::error::TryFromIntError
impl PartialEq for RangeFull
impl PartialEq for Location<'_>
impl PartialEq for core::ptr::alignment::Alignment
impl PartialEq for ParseBoolError
impl PartialEq for Utf8Error
impl PartialEq for RawWaker
impl PartialEq for RawWakerVTable
impl PartialEq for core::time::Duration
impl PartialEq for TryFromFloatSecsError
impl PartialEq for OsStr
impl PartialEq for OsString
impl PartialEq for FileType
impl PartialEq for Permissions
impl PartialEq for std::os::unix::net::ucred::UCred
impl PartialEq for NormalizeError
impl PartialEq for Path
impl PartialEq for PathBuf
impl PartialEq for StripPrefixError
impl PartialEq for ExitCode
impl PartialEq for ExitStatus
impl PartialEq for ExitStatusError
impl PartialEq for Output
impl PartialEq for std::sync::mpsc::RecvError
impl PartialEq for WaitTimeoutResult
impl PartialEq for ThreadId
impl PartialEq for AccessError
impl PartialEq for std::time::Instant
impl PartialEq for SystemTime
impl PartialEq for Parsed
impl PartialEq for InternalFixed
impl PartialEq for InternalNumeric
impl PartialEq for OffsetFormat
impl PartialEq for ParseError
impl PartialEq for Months
impl PartialEq for ParseMonthError
impl PartialEq for NaiveDate
impl PartialEq for NaiveDateDaysIterator
impl PartialEq for NaiveDateWeeksIterator
impl PartialEq for NaiveDateTime
impl PartialEq for IsoWeek
impl PartialEq for Days
impl PartialEq for NaiveWeek
impl PartialEq for NaiveTime
impl PartialEq for FixedOffset
impl PartialEq for Utc
impl PartialEq for OutOfRange
impl PartialEq for TimeDelta
impl PartialEq for ParseWeekdayError
impl PartialEq for WeekdaySet
impl PartialEq for Mime
impl PartialEq for prost::error::DecodeError
impl PartialEq for EncodeError
impl PartialEq for UnknownEnumValue
impl PartialEq for IgnoredAny
impl PartialEq for serde_core::de::value::Error
impl PartialEq for Base64
impl PartialEq for Hex
impl PartialEq for Identity
impl PartialEq for String
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::CommitInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::Event
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::EventAttribute
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ExecTxResult
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ExtendVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ExtendedVoteInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::Misbehavior
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::QuorumHashUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::Request
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestApplySnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestCheckTx
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestEcho
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestExtendVote
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestFinalizeBlock
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestFlush
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestInitChain
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestListSnapshots
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestLoadSnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestOfferSnapshot
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestPrepareProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestProcessProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestQuery
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::RequestVerifyVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::Response
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseApplySnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseCheckTx
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseEcho
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseException
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseExtendVote
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseFinalizeBlock
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseFlush
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseInitChain
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseListSnapshots
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseLoadSnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseOfferSnapshot
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponsePrepareProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseProcessProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseQuery
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ResponseVerifyVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::Snapshot
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ThresholdPublicKeyUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::TxRecord
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::TxResult
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::Validator
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ValidatorSetUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::ValidatorUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc::abci::VoteInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc::crypto::DominoOp
impl PartialEq for tenderdash_proto::tenderdash_grpc::crypto::Proof
impl PartialEq for tenderdash_proto::tenderdash_grpc::crypto::ProofOp
impl PartialEq for tenderdash_proto::tenderdash_grpc::crypto::ProofOps
impl PartialEq for tenderdash_proto::tenderdash_grpc::crypto::PublicKey
impl PartialEq for tenderdash_proto::tenderdash_grpc::crypto::ValueOp
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::AbciParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Block
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::BlockId
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::BlockMeta
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::BlockParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::CanonicalBlockId
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::CanonicalPartSetHeader
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::CanonicalProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::CanonicalVote
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::CanonicalVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Commit
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::ConsensusParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::CoreChainLock
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Data
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::DuplicateVoteEvidence
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Evidence
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::EvidenceList
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::EvidenceParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::HashedParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Header
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::LightBlock
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Part
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::PartSetHeader
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Proposal
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::SignedHeader
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::SimpleValidator
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::StateId
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::SynchronyParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::TimeoutParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::TxProof
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Validator
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::ValidatorParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::ValidatorSet
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::VersionParams
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::Vote
impl PartialEq for tenderdash_proto::tenderdash_grpc::types::VoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc::version::Consensus
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::CommitInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::Event
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::EventAttribute
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ExecTxResult
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ExtendVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ExtendedVoteInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::Misbehavior
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::QuorumHashUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::Request
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestApplySnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestCheckTx
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestEcho
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestExtendVote
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestFinalizeBlock
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestFlush
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestInitChain
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestListSnapshots
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestLoadSnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestOfferSnapshot
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestPrepareProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestProcessProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestQuery
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::RequestVerifyVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::Response
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseApplySnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseCheckTx
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseEcho
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseException
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseExtendVote
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseFinalizeBlock
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseFlush
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseInitChain
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseListSnapshots
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseLoadSnapshotChunk
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseOfferSnapshot
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponsePrepareProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseProcessProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseQuery
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ResponseVerifyVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::Snapshot
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ThresholdPublicKeyUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::TxRecord
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::TxResult
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::Validator
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ValidatorSetUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::ValidatorUpdate
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::abci::VoteInfo
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::crypto::DominoOp
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::crypto::Proof
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::crypto::ProofOp
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::crypto::ProofOps
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::crypto::PublicKey
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::crypto::ValueOp
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::AbciParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Block
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::BlockId
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::BlockMeta
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::BlockParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::CanonicalBlockId
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::CanonicalPartSetHeader
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::CanonicalProposal
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::CanonicalVote
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::CanonicalVoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Commit
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::ConsensusParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::CoreChainLock
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Data
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::DuplicateVoteEvidence
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Evidence
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::EvidenceList
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::EvidenceParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::HashedParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Header
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::LightBlock
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Part
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::PartSetHeader
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Proposal
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::SignedHeader
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::SimpleValidator
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::StateId
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::SynchronyParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::TimeoutParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::TxProof
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Validator
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::ValidatorParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::ValidatorSet
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::VersionParams
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::Vote
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::types::VoteExtension
impl PartialEq for tenderdash_proto::tenderdash_grpc_client::version::Consensus
impl PartialEq for Aborted
impl PartialEq for Alphabet
impl PartialEq for AnyDelimiterCodec
impl PartialEq for Ascii
impl PartialEq for AsciiSet
impl PartialEq for Authority
impl PartialEq for Binary
impl PartialEq for Bytes
impl PartialEq for BytesCodec
impl PartialEq for BytesMut
impl PartialEq for Canceled
impl PartialEq for Code
impl PartialEq for Component
impl PartialEq for ComponentRange
impl PartialEq for CompressionEncoding
impl PartialEq for ConversionRange
impl PartialEq for Cost
impl PartialEq for Count
impl PartialEq for Date
impl PartialEq for DateKind
impl PartialEq for Day
impl PartialEq for DecodeError
impl PartialEq for DecodeMetadata
impl PartialEq for DecodePaddingMode
impl PartialEq for DecodeSliceError
impl PartialEq for DifferentVariant
impl PartialEq for Domain
impl PartialEq for Duration
impl PartialEq for Elapsed
impl PartialEq for Empty
impl PartialEq for EncodeSliceError
impl PartialEq for End
impl PartialEq for Error
impl PartialEq for ErrorKind
impl PartialEq for Field
impl PartialEq for FieldSet
impl PartialEq for FormattedComponents
impl PartialEq for FromStrError
impl PartialEq for GetDisjointMutError
impl PartialEq for GetDisjointMutError
impl PartialEq for HeaderName
impl PartialEq for HeaderValue
impl PartialEq for Hour
impl PartialEq for HttpDate
impl PartialEq for Id
impl PartialEq for Id
impl PartialEq for Id
impl PartialEq for Identifier
impl PartialEq for Ignore
impl PartialEq for InsertError
impl PartialEq for Instant
impl PartialEq for Interest
impl PartialEq for Interest
impl PartialEq for InvalidChunkSize
impl PartialEq for InvalidVariant
impl PartialEq for Kind
impl PartialEq for Level
impl PartialEq for LevelFilter
impl PartialEq for LinesCodec
impl PartialEq for MatchError
impl PartialEq for Metadata<'_>
impl PartialEq for Method
impl PartialEq for MethodFilter
impl PartialEq for Minute
impl PartialEq for MissedTickBehavior
impl PartialEq for Month
impl PartialEq for Month
impl PartialEq for MonthRepr
impl PartialEq for Name
impl PartialEq for OffsetDateTime
impl PartialEq for OffsetHour
impl PartialEq for OffsetMinute
impl PartialEq for OffsetPrecision
impl PartialEq for OffsetSecond
impl PartialEq for Ordinal
impl PartialEq for Padding
impl PartialEq for Parse
impl PartialEq for ParseAlphabetError
impl PartialEq for ParseFromDescription
impl PartialEq for ParseIntError
impl PartialEq for PathAndQuery
impl PartialEq for Period
impl PartialEq for PollNext
impl PartialEq for PrimitiveDateTime
impl PartialEq for Protocol
impl PartialEq for Protocol
impl PartialEq for Protocol
impl PartialEq for Ready
impl PartialEq for Reason
impl PartialEq for ReasonPhrase
impl PartialEq for RecvError
impl PartialEq for RecvError
impl PartialEq for RecvFlags
impl PartialEq for Rfc2822
impl PartialEq for Rfc3339
impl PartialEq for RuntimeFlavor
impl PartialEq for Scheme
impl PartialEq for Second
impl PartialEq for SendError
impl PartialEq for SingleMessageCompressionOverride
impl PartialEq for SockAddr
impl PartialEq for Span
impl PartialEq for StatusCode
impl PartialEq for StreamId
impl PartialEq for Subsecond
impl PartialEq for SubsecondDigits
impl PartialEq for Time
impl PartialEq for TimePrecision
impl PartialEq for Token
impl PartialEq for TryAcquireError
impl PartialEq for TryFromIntError
impl PartialEq for TryFromParsed
impl PartialEq for TryGetError
impl PartialEq for TryRecvError
impl PartialEq for TryRecvError
impl PartialEq for TryRecvError
impl PartialEq for TryReserveError
impl PartialEq for TryReserveError
impl PartialEq for Type
impl PartialEq for UCred
impl PartialEq for UnixTimestamp
impl PartialEq for UnixTimestampPrecision
impl PartialEq for Uri
impl PartialEq for UtcDateTime
impl PartialEq for UtcOffset
impl PartialEq for Version
impl PartialEq for WeekNumber
impl PartialEq for WeekNumberRepr
impl PartialEq for Weekday
impl PartialEq for Weekday
impl PartialEq for WeekdayRepr
impl PartialEq for Year
impl PartialEq for YearRange
impl PartialEq for YearRepr
impl PartialEq<&str> for OsString
impl PartialEq<&CStr> for Cow<'_, CStr>
no_global_oom_handling only.impl PartialEq<&CStr> for CString
impl PartialEq<&CStr> for CStr
impl PartialEq<&[BorrowedFormatItem<'_>]> for BorrowedFormatItem<'_>
impl PartialEq<Cow<'_, CStr>> for CString
no_global_oom_handling only.impl PartialEq<Cow<'_, CStr>> for CStr
no_global_oom_handling only.impl PartialEq<IpAddr> for Ipv4Addr
impl PartialEq<IpAddr> for Ipv6Addr
impl PartialEq<str> for OsStr
impl PartialEq<str> for OsString
impl PartialEq<str> for Path
impl PartialEq<str> for PathBuf
impl PartialEq<str> for Authority
Case-insensitive equality
Examples
let authority: Authority = "HELLO.com".parse().unwrap();
assert_eq!(authority, "hello.coM");
assert_eq!("hello.com", authority);impl PartialEq<str> for Bytes
impl PartialEq<str> for BytesMut
impl PartialEq<str> for HeaderName
impl PartialEq<str> for HeaderValue
impl PartialEq<str> for Method
impl PartialEq<str> for PathAndQuery
impl PartialEq<str> for Scheme
Case-insensitive equality
Examples
let scheme: Scheme = "HTTP".parse().unwrap();
assert_eq!(scheme, *"http");impl PartialEq<str> for Uri
impl PartialEq<u16> for StatusCode
impl PartialEq<CString> for Cow<'_, CStr>
no_global_oom_handling only.impl PartialEq<CString> for CStr
impl PartialEq<CStr> for Cow<'_, CStr>
no_global_oom_handling only.impl PartialEq<CStr> for CString
impl PartialEq<Ipv4Addr> for IpAddr
impl PartialEq<Ipv6Addr> for IpAddr
impl PartialEq<Duration> for Duration
impl PartialEq<OsStr> for str
impl PartialEq<OsStr> for Path
impl PartialEq<OsStr> for PathBuf
impl PartialEq<OsString> for str
impl PartialEq<OsString> for Path
impl PartialEq<OsString> for PathBuf
impl PartialEq<Path> for str
impl PartialEq<Path> for OsStr
impl PartialEq<Path> for OsString
impl PartialEq<Path> for PathBuf
impl PartialEq<Path> for String
impl PartialEq<PathBuf> for str
impl PartialEq<PathBuf> for OsStr
impl PartialEq<PathBuf> for OsString
impl PartialEq<PathBuf> for Path
impl PartialEq<PathBuf> for String
impl PartialEq<String> for Path
impl PartialEq<String> for PathBuf
impl PartialEq<String> for Authority
impl PartialEq<String> for Bytes
impl PartialEq<String> for BytesMut
impl PartialEq<String> for HeaderValue
impl PartialEq<String> for PathAndQuery
impl PartialEq<Vec<u8>> for Bytes
impl PartialEq<Vec<u8>> for BytesMut
impl PartialEq<Authority> for str
impl PartialEq<Authority> for String
impl PartialEq<BorrowedFormatItem<'_>> for &[BorrowedFormatItem<'_>]
impl PartialEq<BorrowedFormatItem<'_>> for Component
impl PartialEq<Bytes> for &str
impl PartialEq<Bytes> for &[u8]
impl PartialEq<Bytes> for str
impl PartialEq<Bytes> for String
impl PartialEq<Bytes> for Vec<u8>
impl PartialEq<Bytes> for BytesMut
impl PartialEq<Bytes> for [u8]
impl PartialEq<BytesMut> for &str
impl PartialEq<BytesMut> for &[u8]
impl PartialEq<BytesMut> for str
impl PartialEq<BytesMut> for String
impl PartialEq<BytesMut> for Vec<u8>
impl PartialEq<BytesMut> for Bytes
impl PartialEq<BytesMut> for [u8]
impl PartialEq<Component> for BorrowedFormatItem<'_>
impl PartialEq<Duration> for core::time::Duration
impl PartialEq<HeaderName> for str
impl PartialEq<HeaderValue> for str
impl PartialEq<HeaderValue> for String
impl PartialEq<HeaderValue> for [u8]
impl PartialEq<Level> for LevelFilter
impl PartialEq<LevelFilter> for Level
impl PartialEq<Method> for str
impl PartialEq<OffsetDateTime> for UtcDateTime
impl PartialEq<PathAndQuery> for str
impl PartialEq<PathAndQuery> for String
impl PartialEq<Scheme> for str
Case-insensitive equality
impl PartialEq<StatusCode> for u16
impl PartialEq<Uri> for str
impl PartialEq<UtcDateTime> for OffsetDateTime
impl PartialEq<[u8]> for Bytes
impl PartialEq<[u8]> for BytesMut
impl PartialEq<[u8]> for HeaderValue
impl<'a> PartialEq for Utf8Pattern<'a>
impl<'a> PartialEq for std::path::Component<'a>
impl<'a> PartialEq for Prefix<'a>
impl<'a> PartialEq for Item<'a>
impl<'a> PartialEq for Unexpected<'a>
impl<'a> PartialEq for PhantomContravariantLifetime<'a>
impl<'a> PartialEq for PhantomCovariantLifetime<'a>
impl<'a> PartialEq for PhantomInvariantLifetime<'a>
impl<'a> PartialEq for Utf8Chunk<'a>
impl<'a> PartialEq for Components<'a>
impl<'a> PartialEq for PrefixComponent<'a>
impl<'a> PartialEq for mime::Name<'a>
impl<'a> PartialEq for BorrowedFormatItem<'a>
impl<'a> PartialEq for Header<'a>
impl<'a> PartialEq for PercentEncode<'a>
impl<'a> PartialEq<&'a str> for Mime
impl<'a> PartialEq<&'a str> for Authority
impl<'a> PartialEq<&'a str> for HeaderName
impl<'a> PartialEq<&'a str> for Method
impl<'a> PartialEq<&'a str> for PathAndQuery
impl<'a> PartialEq<&'a str> for Uri
impl<'a> PartialEq<&'a ByteStr> for Cow<'a, str>
impl<'a> PartialEq<&'a ByteStr> for Cow<'a, ByteStr>
impl<'a> PartialEq<&'a ByteStr> for Cow<'a, [u8]>
impl<'a> PartialEq<&'a OsStr> for Path
impl<'a> PartialEq<&'a OsStr> for PathBuf
impl<'a> PartialEq<&'a Path> for OsStr
impl<'a> PartialEq<&'a Path> for OsString
impl<'a> PartialEq<&'a Path> for PathBuf
impl<'a> PartialEq<&'a HeaderName> for HeaderName
impl<'a> PartialEq<&'a Method> for Method
impl<'a> PartialEq<&str> for ByteString
impl<'a> PartialEq<&str> for ByteStr
impl<'a> PartialEq<&ByteStr> for ByteString
impl<'a> PartialEq<&[u8]> for ByteString
impl<'a> PartialEq<&[u8]> for ByteStr
impl<'a> PartialEq<Cow<'_, str>> for ByteString
impl<'a> PartialEq<Cow<'_, ByteStr>> for ByteString
impl<'a> PartialEq<Cow<'_, [u8]>> for ByteString
impl<'a> PartialEq<Cow<'a, str>> for &'a ByteStr
impl<'a> PartialEq<Cow<'a, ByteStr>> for &'a ByteStr
impl<'a> PartialEq<Cow<'a, OsStr>> for Path
impl<'a> PartialEq<Cow<'a, OsStr>> for PathBuf
impl<'a> PartialEq<Cow<'a, Path>> for OsStr
impl<'a> PartialEq<Cow<'a, Path>> for OsString
impl<'a> PartialEq<Cow<'a, Path>> for Path
impl<'a> PartialEq<Cow<'a, Path>> for PathBuf
impl<'a> PartialEq<Cow<'a, [u8]>> for &'a ByteStr
impl<'a> PartialEq<str> for ByteString
impl<'a> PartialEq<str> for ByteStr
impl<'a> PartialEq<ByteString> for &str
impl<'a> PartialEq<ByteString> for &ByteStr
impl<'a> PartialEq<ByteString> for &[u8]
impl<'a> PartialEq<ByteString> for Cow<'_, str>
impl<'a> PartialEq<ByteString> for Cow<'_, ByteStr>
impl<'a> PartialEq<ByteString> for Cow<'_, [u8]>
impl<'a> PartialEq<ByteString> for str
impl<'a> PartialEq<ByteString> for ByteStr
impl<'a> PartialEq<ByteString> for String
impl<'a> PartialEq<ByteString> for Vec<u8>
impl<'a> PartialEq<ByteString> for [u8]
impl<'a> PartialEq<ByteStr> for &str
impl<'a> PartialEq<ByteStr> for &[u8]
impl<'a> PartialEq<ByteStr> for str
impl<'a> PartialEq<ByteStr> for ByteString
impl<'a> PartialEq<ByteStr> for String
impl<'a> PartialEq<ByteStr> for Vec<u8>
impl<'a> PartialEq<ByteStr> for [u8]
impl<'a> PartialEq<OsStr> for &'a Path
impl<'a> PartialEq<OsStr> for Cow<'a, Path>
impl<'a> PartialEq<OsString> for &'a str
impl<'a> PartialEq<OsString> for &'a Path
impl<'a> PartialEq<OsString> for Cow<'a, Path>
impl<'a> PartialEq<Path> for &'a OsStr
impl<'a> PartialEq<Path> for Cow<'a, OsStr>
impl<'a> PartialEq<Path> for Cow<'a, Path>
impl<'a> PartialEq<PathBuf> for &'a OsStr
impl<'a> PartialEq<PathBuf> for &'a Path
impl<'a> PartialEq<PathBuf> for Cow<'a, OsStr>
impl<'a> PartialEq<PathBuf> for Cow<'a, Path>
impl<'a> PartialEq<Mime> for &'a str
impl<'a> PartialEq<String> for ByteString
impl<'a> PartialEq<String> for ByteStr
impl<'a> PartialEq<Vec<u8>> for ByteString
impl<'a> PartialEq<Vec<u8>> for ByteStr
impl<'a> PartialEq<Authority> for &'a str
impl<'a> PartialEq<HeaderName> for &'a str
impl<'a> PartialEq<HeaderName> for &'a HeaderName
impl<'a> PartialEq<HeaderValue> for &'a str
impl<'a> PartialEq<HeaderValue> for &'a HeaderValue
impl<'a> PartialEq<Method> for &'a str
impl<'a> PartialEq<Method> for &'a Method
impl<'a> PartialEq<PathAndQuery> for &'a str
impl<'a> PartialEq<Uri> for &'a str
impl<'a> PartialEq<[u8]> for ByteString
impl<'a> PartialEq<[u8]> for ByteStr
impl<'a, 'b> PartialEq<&'a str> for String
impl<'a, 'b> PartialEq<&'a OsStr> for OsString
impl<'a, 'b> PartialEq<&'a Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialEq<&'b str> for Cow<'a, str>
impl<'a, 'b> PartialEq<&'b str> for mime::Name<'a>
impl<'a, 'b> PartialEq<&'b OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialEq<&'b OsStr> for Cow<'a, Path>
impl<'a, 'b> PartialEq<&'b Path> for Cow<'a, Path>
impl<'a, 'b> PartialEq<Cow<'a, str>> for &'b str
impl<'a, 'b> PartialEq<Cow<'a, str>> for str
impl<'a, 'b> PartialEq<Cow<'a, str>> for String
impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for &'b OsStr
impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for OsStr
impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for OsString
impl<'a, 'b> PartialEq<Cow<'a, Path>> for &'b OsStr
impl<'a, 'b> PartialEq<Cow<'a, Path>> for &'b Path
impl<'a, 'b> PartialEq<Cow<'b, OsStr>> for &'a Path
impl<'a, 'b> PartialEq<str> for Cow<'a, str>
impl<'a, 'b> PartialEq<str> for String
impl<'a, 'b> PartialEq<OsStr> for Cow<'a, OsStr>
impl<'a, 'b> PartialEq<OsStr> for OsString
impl<'a, 'b> PartialEq<OsString> for &'a OsStr
impl<'a, 'b> PartialEq<OsString> for Cow<'a, OsStr>
impl<'a, 'b> PartialEq<OsString> for OsStr
impl<'a, 'b> PartialEq<Name<'a>> for &'b str
impl<'a, 'b> PartialEq<String> for &'a str
impl<'a, 'b> PartialEq<String> for Cow<'a, str>
impl<'a, 'b> PartialEq<String> for str
impl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
impl<'a, T> PartialEq for GetAll<'a, T>where
T: PartialEq,
impl<'a, T> PartialEq<&'a T> for Bytes
impl<'a, T> PartialEq<&'a T> for BytesMut
impl<'a, T> PartialEq<&'a T> for HeaderValue
impl<'a, VE> PartialEq<&'a str> for MetadataKey<VE>where
VE: ValueEncoding,
impl<'a, VE> PartialEq<&'a MetadataKey<VE>> for MetadataKey<VE>where
VE: ValueEncoding,
impl<'a, VE, T> PartialEq<&'a T> for MetadataValue<VE>
impl<'headers, 'buf> PartialEq for Request<'headers, 'buf>
impl<'headers, 'buf> PartialEq for Response<'headers, 'buf>
impl<'k, 'v> PartialEq for Params<'k, 'v>
impl<A, B> PartialEq<&B> for &A
impl<A, B> PartialEq<&B> for &mut A
impl<A, B> PartialEq<&mut B> for &A
impl<A, B> PartialEq<&mut B> for &mut A
impl<A, B> PartialEq<SmallVec<B>> for SmallVec<A>where
A: Array,
B: Array,
<A as Array>::Item: PartialEq<<B as Array>::Item>,
impl<B, C> PartialEq for ControlFlow<B, C>
impl<Dyn> PartialEq for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<F> PartialEq for Fwhere
F: FnPtr,
impl<H> PartialEq for BuildHasherDefault<H>
impl<Idx> PartialEq for core::ops::range::Range<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for core::ops::range::RangeFrom<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for core::ops::range::RangeInclusive<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for RangeTo<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for core::ops::range::RangeToInclusive<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for core::range::Range<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for core::range::RangeFrom<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for core::range::RangeInclusive<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for core::range::RangeToInclusive<Idx>where
Idx: PartialEq,
impl<K, V1, S1, V2, S2> PartialEq<IndexMap<K, V2, S2>> for IndexMap<K, V1, S1>
impl<K, V, A> PartialEq for BTreeMap<K, V, A>
impl<K, V, K2, V2> PartialEq<Slice<K2, V2>> for Slice<K, V>
impl<K, V, K2, V2> PartialEq<Slice<K2, V2>> for [(K, V)]
impl<K, V, K2, V2> PartialEq<[(K2, V2)]> for Slice<K, V>
impl<K, V, K2, V2, const N: usize> PartialEq<[(K2, V2); N]> for Slice<K, V>
impl<K, V, S> PartialEq for std::collections::hash::map::HashMap<K, V, S>
impl<K, V, S, A> PartialEq for HashMap<K, V, S, A>
impl<K, V, const N: usize, K2, V2> PartialEq<Slice<K2, V2>> for [(K, V); N]
impl<Ptr, Q> PartialEq<Pin<Q>> for Pin<Ptr>
impl<T> PartialEq for Option<T>where
T: PartialEq,
impl<T> PartialEq for Bound<T>where
T: PartialEq,
impl<T> PartialEq for Poll<T>where
T: PartialEq,
impl<T> PartialEq for std::sync::mpmc::error::SendTimeoutError<T>where
T: PartialEq,
impl<T> PartialEq for std::sync::mpsc::TrySendError<T>where
T: PartialEq,
impl<T> PartialEq for LocalResult<T>where
T: PartialEq,
impl<T> PartialEq for *const Twhere
T: ?Sized,
Pointer equality is by address, as produced by the <*const T>::addr method.
impl<T> PartialEq for *mut Twhere
T: ?Sized,
Pointer equality is by address, as produced by the <*mut T>::addr method.
impl<T> PartialEq for (T₁, T₂, …, Tₙ)where
T: PartialEq,
This trait is implemented for tuples up to twelve items long.