Send

Trait Send 

1.0.0 · Source
pub unsafe auto trait Send { }
Types that can be transferred across thread boundaries.

This trait is automatically implemented when the compiler determines it’s appropriate.

An example of a non-Send type is the reference-counting pointer rc::Rc. If two threads attempt to clone Rcs that point to the same reference-counted value, they might try to update the reference count at the same time, which is undefined behavior because Rc doesn’t use atomic operations. Its cousin sync::Arc does use atomic operations (incurring some overhead) and thus is Send.

See the Nomicon and the Sync trait for more details.

Implementors

1.0.0 · Source

impl !Send for Arguments<'_>

Source

impl !Send for LocalWaker

1.26.0 · Source

impl !Send for Args

1.26.0 · Source

impl !Send for ArgsOs

1.6.0 · Source

impl Send for alloc::string::Drain<'_>

1.0.0 · Source

impl Send for TypeId

Source

impl Send for core::ffi::c_str::Bytes<'_>

1.10.0 · Source

impl Send for Location<'_>

1.36.0 · Source

impl Send for Waker



impl Send for AbortHandle



impl Send for AtomicWaker



impl Send for AtomicWaker



impl Send for Bytes



impl Send for BytesMut

1.44.0 · Source

impl<'a> Send for IoSlice<'a>

1.44.0 · Source

impl<'a> Send for IoSliceMut<'a>



impl<'a> Send for Notified<'a>



impl<'a, T> Send for Drain<'a, T>
where T: Send + Array,



impl<'a, T> Send for Drain<'a, T>
where T: Send,



impl<'a, T> Send for Iter<'a, T>
where T: Sync,



impl<'a, T> Send for IterMut<'a, T>
where T: Send,



impl<'a, T> Send for MappedMutexGuard<'a, T>
where T: Send + 'a + ?Sized,



impl<'a, T> Send for ValueDrain<'a, T>
where T: Send,



impl<'a, T> Send for ValueIterMut<'a, T>
where T: Send,



impl<A> Send for SmallVec<A>
where A: Array, <A as Array>::Item: Send,

Source

impl<Dyn> Send for DynMetadata<Dyn>
where Dyn: ?Sized,



impl<Fut> Send for FuturesUnordered<Fut>
where Fut: Send,



impl<Fut> Send for IntoIter<Fut>
where Fut: Send + Unpin,



impl<Fut> Send for IterPinMut<'_, Fut>
where Fut: Send,



impl<Fut> Send for IterPinRef<'_, Fut>
where Fut: Send,



impl<K, V> Send for IterMut<'_, K, V>
where K: Send, V: Send,



impl<K, V, S, A> Send for OccupiedEntry<'_, K, V, S, A>
where K: Send, V: Send, S: Send, A: Send + Allocator,

1.0.0 · Source

impl<T> !Send for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for *mut T
where T: ?Sized,

1.25.0 · Source

impl<T> !Send for NonNull<T>
where T: ?Sized,

NonNull pointers are not Send because the data they reference may be aliased.

Source

impl<T> !Send for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::mutex::MutexGuard<'_, T>
where T: ?Sized,

A MutexGuard is not Send to maximize platform portability.

On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to release mutex locks on the same thread they were acquired. For this reason, MutexGuard must not implement Send to prevent it being dropped from another thread.

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> !Send for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: ?Sized,

Source

impl<T> !Send for ReentrantLockGuard<'_, T>
where T: ?Sized,

1.0.0 · Source

impl<T> Send for &T
where T: Sync + ?Sized,

Source

impl<T> Send for ThinBox<T>
where T: Send + ?Sized,

ThinBox<T> is Send if T is Send because the data is owned.

1.0.0 · Source

impl<T> Send for alloc::collections::linked_list::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for alloc::collections::linked_list::IterMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for Cell<T>
where T: Send + ?Sized,

1.0.0 · Source

impl<T> Send for RefCell<T>
where T: Send + ?Sized,

1.28.0 · Source

impl<T> Send for NonZero<T>

1.31.0 · Source

impl<T> Send for ChunksExactMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for ChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for core::slice::iter::Iter<'_, T>
where T: Sync,

1.0.0 · Source

impl<T> Send for core::slice::iter::IterMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksExactMut<'_, T>
where T: Send,

1.31.0 · Source

impl<T> Send for RChunksMut<'_, T>
where T: Send,

1.0.0 · Source

impl<T> Send for AtomicPtr<T>

Available on target_has_atomic_load_store=ptr only.
Source

impl<T> Send for std::sync::mpmc::Receiver<T>
where T: Send,

Source

impl<T> Send for std::sync::mpmc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Receiver<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::mpsc::Sender<T>
where T: Send,

1.0.0 · Source

impl<T> Send for SyncSender<T>
where T: Send,

Source

impl<T> Send for std::sync::nonpoison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

Source

impl<T> Send for std::sync::nonpoison::rwlock::RwLock<T>
where T: Send + ?Sized,

1.70.0 · Source

impl<T> Send for OnceLock<T>
where T: Send,

1.0.0 · Source

impl<T> Send for std::sync::poison::mutex::Mutex<T>
where T: Send + ?Sized,

T must be Send for a Mutex to be Send because it is possible to acquire the owned T from the Mutex via into_inner.

1.0.0 · Source

impl<T> Send for std::sync::poison::rwlock::RwLock<T>
where T: Send + ?Sized,

Source

impl<T> Send for ReentrantLock<T>
where T: Send + ?Sized,

1.29.0 · Source

impl<T> Send for std::thread::join_handle::JoinHandle<T>



impl<T> Send for Empty<T>



impl<T> Send for FutureObj<'_, T>



impl<T> Send for JoinHandle<T>
where T: Send,



impl<T> Send for Mutex<T>
where T: Send + ?Sized,



impl<T> Send for Mutex<T>
where T: Send + ?Sized,



impl<T> Send for MutexGuard<'_, T>
where T: Send + ?Sized,



impl<T> Send for MutexLockFuture<'_, T>
where T: Send + ?Sized,



impl<T> Send for OnceCell<T>
where T: Send,



impl<T> Send for OwnedMutexGuard<T>
where T: Send + ?Sized,



impl<T> Send for OwnedMutexLockFuture<T>
where T: Send + ?Sized,



impl<T> Send for OwnedRwLockWriteGuard<T>
where T: Send + Sync + ?Sized,



impl<T> Send for Pending<T>



impl<T> Send for ReadHalf<T>
where T: Send,



impl<T> Send for RwLock<T>
where T: Send + ?Sized,



impl<T> Send for RwLockMappedWriteGuard<'_, T>
where T: Send + Sync + ?Sized,



impl<T> Send for RwLockReadGuard<'_, T>
where T: Sync + ?Sized,



impl<T> Send for RwLockWriteGuard<'_, T>
where T: Send + Sync + ?Sized,



impl<T> Send for SetOnce<T>
where T: Send,



impl<T> Send for TryLock<T>
where T: Send,



impl<T> Send for WriteHalf<T>
where T: Send,

1.0.0 · Source

impl<T, A> !Send for Rc<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> !Send for UniqueRc<T, A>
where A: Allocator, T: ?Sized,

1.4.0 · Source

impl<T, A> !Send for alloc::rc::Weak<T, A>
where A: Allocator, T: ?Sized,

Source

impl<T, A> Send for Cursor<'_, T, A>
where T: Sync, A: Allocator + Sync,

Source

impl<T, A> Send for CursorMut<'_, T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for LinkedList<T, A>
where T: Send, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for alloc::collections::vec_deque::drain::Drain<'_, T, A>
where T: Send, A: Allocator + Send,

1.0.0 · Source

impl<T, A> Send for Arc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

Source

impl<T, A> Send for UniqueArc<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

1.4.0 · Source

impl<T, A> Send for alloc::sync::Weak<T, A>
where T: Sync + Send + ?Sized, A: Allocator + Send,

1.6.0 · Source

impl<T, A> Send for tenderdash_proto::vec::Drain<'_, T, A>
where T: Send, A: Send + Allocator,

1.0.0 · Source

impl<T, A> Send for tenderdash_proto::vec::IntoIter<T, A>
where T: Send, A: Allocator + Send,



impl<T, A> Send for OccupiedEntry<'_, T, A>
where T: Send, A: Send + Allocator,



impl<T, U> Send for MappedMutexGuard<'_, T, U>
where T: Send + ?Sized, U: Send + ?Sized,



impl<T, U> Send for OwnedMappedMutexGuard<T, U>
where T: Send + ?Sized, U: Send + ?Sized,



impl<T, U> Send for OwnedRwLockMappedWriteGuard<T, U>
where T: Send + Sync + ?Sized, U: Send + Sync + ?Sized,



impl<T, U> Send for OwnedRwLockReadGuard<T, U>
where T: Send + Sync + ?Sized, U: Sync + ?Sized,

Source

impl<Tz> Send for Date<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Send,

Auto implementors



impl Send for Error



impl Send for tenderdash_proto::tenderdash_grpc::abci::CheckTxType



impl Send for tenderdash_proto::tenderdash_grpc::abci::MisbehaviorType



impl Send for tenderdash_proto::tenderdash_grpc::abci::request::Value



impl Send for tenderdash_proto::tenderdash_grpc::abci::response::Value



impl Send for tenderdash_proto::tenderdash_grpc::abci::response_apply_snapshot_chunk::Result



impl Send for tenderdash_proto::tenderdash_grpc::abci::response_offer_snapshot::Result



impl Send for tenderdash_proto::tenderdash_grpc::abci::response_process_proposal::ProposalStatus



impl Send for tenderdash_proto::tenderdash_grpc::abci::response_verify_vote_extension::VerifyStatus



impl Send for tenderdash_proto::tenderdash_grpc::abci::tx_record::TxAction



impl Send for tenderdash_proto::tenderdash_grpc::crypto::public_key::Sum



impl Send for tenderdash_proto::tenderdash_grpc::types::BlockIdFlag



impl Send for tenderdash_proto::tenderdash_grpc::types::SignedMsgType



impl Send for tenderdash_proto::tenderdash_grpc::types::VoteExtensionType



impl Send for tenderdash_proto::tenderdash_grpc::types::evidence::Sum



impl Send for tenderdash_proto::tenderdash_grpc::types::version_params::ConsensusVersion



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::CheckTxType



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::MisbehaviorType



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::request::Value



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::response::Value



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::response_apply_snapshot_chunk::Result



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::response_offer_snapshot::Result



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::response_process_proposal::ProposalStatus



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::response_verify_vote_extension::VerifyStatus



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::tx_record::TxAction



impl Send for tenderdash_proto::tenderdash_grpc_client::crypto::public_key::Sum



impl Send for tenderdash_proto::tenderdash_grpc_client::types::BlockIdFlag



impl Send for tenderdash_proto::tenderdash_grpc_client::types::SignedMsgType



impl Send for tenderdash_proto::tenderdash_grpc_client::types::VoteExtensionType



impl Send for tenderdash_proto::tenderdash_grpc_client::types::evidence::Sum



impl Send for tenderdash_proto::tenderdash_grpc_client::types::version_params::ConsensusVersion



impl Send for Duration



impl Send for Timestamp



impl Send for Rfc3339



impl Send for String



impl Send for tenderdash_proto::tenderdash_grpc::abci::CommitInfo



impl Send for tenderdash_proto::tenderdash_grpc::abci::Event



impl Send for tenderdash_proto::tenderdash_grpc::abci::EventAttribute



impl Send for tenderdash_proto::tenderdash_grpc::abci::ExecTxResult



impl Send for tenderdash_proto::tenderdash_grpc::abci::ExtendVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc::abci::ExtendedVoteInfo



impl Send for tenderdash_proto::tenderdash_grpc::abci::Misbehavior



impl Send for tenderdash_proto::tenderdash_grpc::abci::QuorumHashUpdate



impl Send for tenderdash_proto::tenderdash_grpc::abci::Request



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestApplySnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestCheckTx



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestEcho



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestExtendVote



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestFinalizeBlock



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestFlush



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestInfo



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestInitChain



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestListSnapshots



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestLoadSnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestOfferSnapshot



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestPrepareProposal



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestProcessProposal



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestQuery



impl Send for tenderdash_proto::tenderdash_grpc::abci::RequestVerifyVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc::abci::Response



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseApplySnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseCheckTx



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseEcho



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseException



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseExtendVote



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseFinalizeBlock



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseFlush



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseInfo



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseInitChain



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseListSnapshots



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseLoadSnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseOfferSnapshot



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponsePrepareProposal



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseProcessProposal



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseQuery



impl Send for tenderdash_proto::tenderdash_grpc::abci::ResponseVerifyVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc::abci::Snapshot



impl Send for tenderdash_proto::tenderdash_grpc::abci::ThresholdPublicKeyUpdate



impl Send for tenderdash_proto::tenderdash_grpc::abci::TxRecord



impl Send for tenderdash_proto::tenderdash_grpc::abci::TxResult



impl Send for tenderdash_proto::tenderdash_grpc::abci::Validator



impl Send for tenderdash_proto::tenderdash_grpc::abci::ValidatorSetUpdate



impl Send for tenderdash_proto::tenderdash_grpc::abci::ValidatorUpdate



impl Send for tenderdash_proto::tenderdash_grpc::abci::VoteInfo



impl Send for tenderdash_proto::tenderdash_grpc::crypto::DominoOp



impl Send for tenderdash_proto::tenderdash_grpc::crypto::Proof



impl Send for tenderdash_proto::tenderdash_grpc::crypto::ProofOp



impl Send for tenderdash_proto::tenderdash_grpc::crypto::ProofOps



impl Send for tenderdash_proto::tenderdash_grpc::crypto::PublicKey



impl Send for tenderdash_proto::tenderdash_grpc::crypto::ValueOp



impl Send for tenderdash_proto::tenderdash_grpc::types::AbciParams



impl Send for tenderdash_proto::tenderdash_grpc::types::Block



impl Send for tenderdash_proto::tenderdash_grpc::types::BlockId



impl Send for tenderdash_proto::tenderdash_grpc::types::BlockMeta



impl Send for tenderdash_proto::tenderdash_grpc::types::BlockParams



impl Send for tenderdash_proto::tenderdash_grpc::types::CanonicalBlockId



impl Send for tenderdash_proto::tenderdash_grpc::types::CanonicalPartSetHeader



impl Send for tenderdash_proto::tenderdash_grpc::types::CanonicalProposal



impl Send for tenderdash_proto::tenderdash_grpc::types::CanonicalVote



impl Send for tenderdash_proto::tenderdash_grpc::types::CanonicalVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc::types::Commit



impl Send for tenderdash_proto::tenderdash_grpc::types::ConsensusParams



impl Send for tenderdash_proto::tenderdash_grpc::types::CoreChainLock



impl Send for tenderdash_proto::tenderdash_grpc::types::Data



impl Send for tenderdash_proto::tenderdash_grpc::types::DuplicateVoteEvidence



impl Send for tenderdash_proto::tenderdash_grpc::types::Evidence



impl Send for tenderdash_proto::tenderdash_grpc::types::EvidenceList



impl Send for tenderdash_proto::tenderdash_grpc::types::EvidenceParams



impl Send for tenderdash_proto::tenderdash_grpc::types::HashedParams



impl Send for tenderdash_proto::tenderdash_grpc::types::Header



impl Send for tenderdash_proto::tenderdash_grpc::types::LightBlock



impl Send for tenderdash_proto::tenderdash_grpc::types::Part



impl Send for tenderdash_proto::tenderdash_grpc::types::PartSetHeader



impl Send for tenderdash_proto::tenderdash_grpc::types::Proposal



impl Send for tenderdash_proto::tenderdash_grpc::types::SignedHeader



impl Send for tenderdash_proto::tenderdash_grpc::types::SimpleValidator



impl Send for tenderdash_proto::tenderdash_grpc::types::StateId



impl Send for tenderdash_proto::tenderdash_grpc::types::SynchronyParams



impl Send for tenderdash_proto::tenderdash_grpc::types::TimeoutParams



impl Send for tenderdash_proto::tenderdash_grpc::types::TxProof



impl Send for tenderdash_proto::tenderdash_grpc::types::Validator



impl Send for tenderdash_proto::tenderdash_grpc::types::ValidatorParams



impl Send for tenderdash_proto::tenderdash_grpc::types::ValidatorSet



impl Send for tenderdash_proto::tenderdash_grpc::types::VersionParams



impl Send for tenderdash_proto::tenderdash_grpc::types::Vote



impl Send for tenderdash_proto::tenderdash_grpc::types::VoteExtension



impl Send for tenderdash_proto::tenderdash_grpc::version::Consensus



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::CommitInfo



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::Event



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::EventAttribute



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ExecTxResult



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ExtendVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ExtendedVoteInfo



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::Misbehavior



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::QuorumHashUpdate



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::Request



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestApplySnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestCheckTx



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestEcho



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestExtendVote



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestFinalizeBlock



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestFlush



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestInfo



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestInitChain



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestListSnapshots



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestLoadSnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestOfferSnapshot



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestPrepareProposal



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestProcessProposal



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestQuery



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::RequestVerifyVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::Response



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseApplySnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseCheckTx



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseEcho



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseException



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseExtendVote



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseFinalizeBlock



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseFlush



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseInfo



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseInitChain



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseListSnapshots



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseLoadSnapshotChunk



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseOfferSnapshot



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponsePrepareProposal



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseProcessProposal



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseQuery



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ResponseVerifyVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::Snapshot



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ThresholdPublicKeyUpdate



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::TxRecord



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::TxResult



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::Validator



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ValidatorSetUpdate



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::ValidatorUpdate



impl Send for tenderdash_proto::tenderdash_grpc_client::abci::VoteInfo



impl Send for tenderdash_proto::tenderdash_grpc_client::crypto::DominoOp



impl Send for tenderdash_proto::tenderdash_grpc_client::crypto::Proof



impl Send for tenderdash_proto::tenderdash_grpc_client::crypto::ProofOp



impl Send for tenderdash_proto::tenderdash_grpc_client::crypto::ProofOps



impl Send for tenderdash_proto::tenderdash_grpc_client::crypto::PublicKey



impl Send for tenderdash_proto::tenderdash_grpc_client::crypto::ValueOp



impl Send for tenderdash_proto::tenderdash_grpc_client::types::AbciParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Block



impl Send for tenderdash_proto::tenderdash_grpc_client::types::BlockId



impl Send for tenderdash_proto::tenderdash_grpc_client::types::BlockMeta



impl Send for tenderdash_proto::tenderdash_grpc_client::types::BlockParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::CanonicalBlockId



impl Send for tenderdash_proto::tenderdash_grpc_client::types::CanonicalPartSetHeader



impl Send for tenderdash_proto::tenderdash_grpc_client::types::CanonicalProposal



impl Send for tenderdash_proto::tenderdash_grpc_client::types::CanonicalVote



impl Send for tenderdash_proto::tenderdash_grpc_client::types::CanonicalVoteExtension



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Commit



impl Send for tenderdash_proto::tenderdash_grpc_client::types::ConsensusParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::CoreChainLock



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Data



impl Send for tenderdash_proto::tenderdash_grpc_client::types::DuplicateVoteEvidence



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Evidence



impl Send for tenderdash_proto::tenderdash_grpc_client::types::EvidenceList



impl Send for tenderdash_proto::tenderdash_grpc_client::types::EvidenceParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::HashedParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Header



impl Send for tenderdash_proto::tenderdash_grpc_client::types::LightBlock



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Part



impl Send for tenderdash_proto::tenderdash_grpc_client::types::PartSetHeader



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Proposal



impl Send for tenderdash_proto::tenderdash_grpc_client::types::SignedHeader



impl Send for tenderdash_proto::tenderdash_grpc_client::types::SimpleValidator



impl Send for tenderdash_proto::tenderdash_grpc_client::types::StateId



impl Send for tenderdash_proto::tenderdash_grpc_client::types::SynchronyParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::TimeoutParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::TxProof



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Validator



impl Send for tenderdash_proto::tenderdash_grpc_client::types::ValidatorParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::ValidatorSet



impl Send for tenderdash_proto::tenderdash_grpc_client::types::VersionParams



impl Send for tenderdash_proto::tenderdash_grpc_client::types::Vote



impl Send for tenderdash_proto::tenderdash_grpc_client::types::VoteExtension



impl Send for tenderdash_proto::tenderdash_grpc_client::version::Consensus



impl<'a, I, A> Send for Splice<'a, I, A>
where I: Send, <I as Iterator>::Item: Send, A: Send,



impl<'a, T, A> Send for PeekMut<'a, T, A>
where A: Send, T: Send,



impl<'a, T, F, A> Send for ExtractIf<'a, T, F, A>
where F: Send, A: Send, T: Send,



impl<T> Send for Option<T>
where T: Send,



impl<T> Send for tenderdash_proto::tenderdash_grpc::abci::abci_application_client::AbciApplicationClient<T>
where T: Send,



impl<T> Send for AbciApplicationServer<T>
where T: Sync + Send,



impl<T> Send for tenderdash_proto::tenderdash_grpc_client::abci::abci_application_client::AbciApplicationClient<T>
where T: Send,



impl<T, A> Send for Box<T, A>
where A: Send, T: Send + ?Sized,



impl<T, A> Send for Vec<T, A>
where A: Send, T: Send,



impl<T, E> Send for tenderdash_proto::Result<T, E>
where T: Send, E: Send,